<?php
/**
 * Checkboxes list filter info
 */
?>
<div class="conatiner-columns">
	<div class="column">
		<p><?php _e( 'Filter the posts or products by post or meta date using periods like day, week, month, year, and custom range.', 'jet-smart-filters' ); ?></p>
		<ul class="help-list">
			<li><a href="#"><?php _e( 'How to Use Date Period Filter', 'jet-smart-filters' ); ?></a></li>
			<li><a href="#"><?php _e( 'How to Set Indexer Option for Filters ', 'jet-smart-filters' ); ?></a></li>
			<li><a href="#"><?php _e( 'Visual Filter Overview', 'jet-smart-filters' ); ?></a></li>
		</ul>
		<a href="#" class="link"><?php _e( 'Learn More', 'jet-smart-filters' ); ?></a>
	</div>
	<div class="column">
		<div class="video">
			<svg width="268" height="149" viewBox="0 0 268 149" fill="none" xmlns="http://www.w3.org/2000/svg">
				<rect width="268" height="149" rx="4" fill="#B0B8BF"/>
				<path fill-rule="evenodd" clip-rule="evenodd" d="M120.962 86.3369C120.962 88.6593 123.558 90.0378 125.482 88.7374L143.045 76.8669C144.745 75.718 144.745 73.2149 143.045 72.066L125.482 60.1955C123.558 58.8951 120.962 60.2736 120.962 62.596V86.3369Z" fill="white" fill-opacity="0.6"/>
			</svg>
		</div>
		<a href="#">How to Set Indexer Option for Filters</a>
	</div>
</div>